# -*- coding: utf-8 -*-
"""
Grabs the tests in doctest
"""
__docformat__ = 'restructuredtext'

import unittest
import doctest
import sys
import os
import shutil
import popen2
import tempfile
#from zopeskel.tests.test_zopeskeldocs import rmdit, paster, read_sh, ls, cd, config, cat, touch, ZopeSkelLayer, doc_suite, test_suite

from zope.testing import doctest

current_dir = os.path.abspath(os.path.dirname(__file__))

def rmdir(*args):
    dirname = os.path.join(*args)
    if os.path.isdir(dirname):
        shutil.rmtree(dirname)


def paster(cmd):
    print "paster %s" % cmd
    from paste.script import command
    #the overwite option for the create command defaults to True
    #but in the paste.script.command it defaults to False.
    #so we fixe it here
    if 'create' in cmd:
        cmd += " --overwrite=1"
    args = cmd.split()
    options, args = command.parser.parse_args(args)
    options.base_parser = command.parser
    command.system_plugins.extend(options.plugins or [])
    commands = command.get_commands()
    command_name = args[0]
    if command_name not in commands:
        command = command.NotFoundCommand
    else:
        command = commands[command_name].load()
    runner = command(command_name)
    runner.run(args[1:])


def read_sh(cmd):
    _cmd = cmd
    old = sys.stdout 
    child_stdout_and_stderr, child_stdin = popen2.popen4(_cmd)
    child_stdin.close()
    return child_stdout_and_stderr.read()


def ls(*args):
    dirname = os.path.join(*args)
    if os.path.isdir(dirname):
        filenames = os.listdir(dirname)
        for filename in sorted(filenames):
            print filename
    else:
        print 'No directory named %s' % dirname


def cd(*args):
    dirname = os.path.join(*args)
    os.chdir(dirname)


def config(filename):
    return os.path.join(current_dir, filename)


def cat(*args):
    filename = os.path.join(*args)
    if os.path.isfile(filename):
        print open(filename).read()
    else:
        print 'No file named %s' % filename


def touch(*args, **kwargs):
    filename = os.path.join(*args)
    open(filename, 'w').write(kwargs.get('data',''))


class PasterTemplatesLayer:

    temp_dir = None

    @classmethod
    def testSetUp(self):
        self.temp_dir = tempfile.mkdtemp()
        cd(self.temp_dir)
      
    @classmethod
    def testTearDown(self):
        shutil.rmtree(self.temp_dir, ignore_errors=True)
        self.temp_dir = None

        from pkg_resources import working_set as ws
        #cleanup entries in the working set
        for k, v in ws.by_key.items():
            if not os.path.exists(v.location):
                del ws.by_key[k]

        for i in reversed(range(len(ws.entries))):
            if not os.path.exists(ws.entries[i]):
                del ws.entries[i]

        sys.path = ws.entries[:]


def doc_suite(test_dir, setUp=None, tearDown=None, globs=None):
    """Returns a test suite, based on doctests found in /doctest."""
    suite = []
    if globs is None:
        globs = globals()

    flags = (doctest.ELLIPSIS | doctest.NORMALIZE_WHITESPACE |
             doctest.REPORT_ONLY_FIRST_FAILURE)

    package_dir = os.path.split(test_dir)[0]
    if package_dir not in sys.path:
        sys.path.append(package_dir)

    doctest_dir = os.path.join(package_dir, 'docs')

    # filtering files on extension
    docs = [os.path.join(doctest_dir, doc) for doc in
            os.listdir(doctest_dir) if doc.endswith('.txt')]

    for test in docs:
        suite.append(doctest.DocFileSuite(test, optionflags=flags, 
                                          globs=globs, setUp=setUp, 
                                          tearDown=tearDown,
                                          module_relative=False))

    return unittest.TestSuite(suite)

def test_suite():
    """returns the test suite"""
    suite = doc_suite(current_dir)
    suite.layer = PasterTemplatesLayer
    return suite
    
if __name__ == '__main__':
    unittest.main(defaultTest='test_suite')




# -*- coding: utf-8 -*-
from setuptools import setup, find_packages
import os

version = '0.5.1'

setup(name='sc.paster.package',
      version=version,
      description="Paster templates da Simples Consultoria",
      long_description=open("README.txt").read() + "\n" +
                       open(os.path.join("docs", "HISTORY.txt")).read(),
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
        ],
      keywords='web zope plone development simples_consultoria',
      author='Erico Andrei',
      author_email='erico@simplesconsultoria.com.br',
      url='http://www.simplesconsultoria.com.br/',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['sc', 'sc.paster'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'ZopeSkel'
      ],
      tests_require=['zope.testing', 'zc.buildout', 'Cheetah', 'PasteScript','ZopeSkel'],
      test_suite='sc.paster.package.tests.test_templates.test_suite',
      entry_points="""
        [paste.paster_create_template]
        portal_package = sc.paster.package:Package
      """,
      )



# -*- coding: utf-8 -*-
import copy
from zopeskel.base import get_var
from zopeskel.base import var

from zopeskel.plone_app import PloneApp

class Package(PloneApp):
    _template_dir = 'templates/portal_package'
    summary = "Package usado em projetos Plone"
    required_templates = ['plone_app']
    use_cheetah = True
    use_local_commands = False
    vars = copy.deepcopy(PloneApp.vars)
    get_var(vars, 'namespace_package').default = 'sc'
    get_var(vars, 'namespace_package').description = 'Namespace principal (sempre sc)'
    get_var(vars, 'namespace_package2').default = 's17'
    get_var(vars, 'namespace_package2').description = 'Usualmente o nome base do produto'
    get_var(vars, 'package').default = 'bookshelf'
    get_var(vars, 'package').description = 'Nome do produto'   
    get_var(vars, 'version').default = '0.5'
    get_var(vars, 'author').default = 'Simples Consultoria'
    get_var(vars, 'author_email').default = 'products@simplesconsultoria.com.br'
    get_var(vars, 'url').default = 'http://www.simplesconsultoria.com.br/'
    
    def post(self, command, output_dir, vars):
        super(Package, self).pre(command, output_dir, vars)
